@@ -675,6 +675,10 @@ class Base(Controller):
                 "help" : "Id of the finished task",
                 "action": "store"
             }),
+            (['-ws'],{
+                "help": "Workspace name (e.g. Daily) otherwiwise grabs the first one",
+                "action": "store"
+            }),
             (['-f'],{
                 "help" : "Filter TODOs for ls",
                 "action": "store"
@@ -686,7 +690,7 @@ class Base(Controller):
         project = int(self.app.pargs.p or 0)
 
         if self.app.pargs.action=='add':
-            add_todo(self.app.pargs.t, self.app.pargs.l, project)
+            add_todo(self.app.pargs.t, self.app.pargs.l, self.app.pargs.ws, project)
         elif self.app.pargs.action=='ls':
             asana_list_todos(
                 self.app.pargs.p,
@@ -743,6 +747,43 @@ class Base(Controller):
         else:
             raise NotImplemented("Action must be one of {add, ls, dn}")
         
+    @ex(
+        help="Manage outlook calendar",
+        arguments=[
+            (['action'],{
+                "help" : "One of {add, ls, del}",
+                "action": "store"
+            }),
+            (['-t'],{
+                "help": "Title of the event",
+                "action": "store"
+            }),
+            (['-i','--invite'],{
+                "help": "Invitee email(s) separated by commas",
+                "action": "store"
+            }),
+            (['-s','--start'],{
+                "help": "Start time of the event",
+                "action": "store"
+            }),
+            (['-d','--duration'],{
+                "help": "Duration of the event in minutes",
+                "action": "store"
+            })
+        ]
+    )
+    def ms_outlook(self):
+        from ..ext.ms_outlook import add_event, list_events, delete_event
+        if self.app.pargs.action=='add':
+            add_event(self.app.pargs.t, self.app.pargs.i, self.app.pargs.s, self.app.pargs.d)
+        elif self.app.pargs.action=='ls':
+            list_events()
+        elif self.app.pargs.action=='del':
+            delete_event(self.app.pargs.i)
+        else:
+            raise NotImplemented("Action must be one of {add, ls, del}")
+    
+         
     # TODO: implement this as command
     # likely easiest as just alias dt='python -m dt.main'
     # echo "alias dt='python -m dt.main'" > ~/.bashrc; source ~/.basshrc
