@@ -32,7 +32,7 @@ def asana_list_todos(workspace_name,filtering):
     if filtering is None: filtering = 'due'
     
     df = asana_get_todos(workspace_name,filtering)
-    df = df[['name',"due_on", "completed", "notes"]] # projects
+    df = df[['gid','name',"due_on", "completed", "notes"]] # projects
     
     if filtering == 'done':
         df = df[df['completed'] == True]
@@ -74,7 +74,7 @@ def asana_get_todos(workspace_name,filtering):
     df = pd.DataFrame(tasks)
     return df
     
-def add_todo(task_text, expected_duration, project_id=0):
+def add_todo(task_text, expected_duration, workspace_name, project_id=0):
     tm = time.localtime()
     
     if expected_duration is None:
@@ -86,8 +86,12 @@ def add_todo(task_text, expected_duration, project_id=0):
     
     client = get_client()
     me = client.users.me()
-    workspace_id = me['workspaces'][0]['gid']
-    
+    if len(me['workspaces'])!=1:
+        workspace_name = 'Daily'
+        workspace_id = [ w['gid'] for w in me['workspaces'] if w['name'] == workspace_name][0]
+    else:
+        workspace_id = me['workspaces'][0]['gid']    
+        
     projects = list(client.projects.get_projects_for_workspace(workspace_id))
     
     # docs https://developers.asana.com/docs/create-a-task
